@@ -1,4 +1,4 @@
-from src.common_microservices.messages import Messages
+from common_structure_microservices.messages import Messages
 from rest_framework.pagination import LimitOffsetPagination
 from rest_framework.response import Response
 
